.. :changelog:

History
=======

1.1.0 (2019-09-09)
------------------

Long awaited stable release:

Changes can be viewed:
https://github.com/vbabiy/djangorestframework-camel-case/compare/e6db468...39ae6bb

0.1.0 (2013-12-20)
------------------

* First release on PyPI.
